@@ -114,7 +114,7 @@ class GithubUtilsApi:
         url = self.github_url + "/orgs/" + organization_name + "/teams/" + team_slug_name + "/memberships/" + github_username
         return self.__request("DELETE", url, params)
 
-    def list_repositories(self, organization_name=None, type="all", sort="created", per_page=None, page=None):
+    def list_repositories(self, organization_name=None, type="all", sort="created", per_page=30, page=1):
         '''
         This method allows listing all repositories in a GitHub organization
         According API docs: https://docs.github.com/es/rest/reference/repos#list-organization-repositories
@@ -126,15 +126,8 @@ class GithubUtilsApi:
         :return: request
         '''
         params = {}
-        if type:
-            params['type'] = type
-        if sort:
-            params['sort'] = sort
-        if per_page:
-            params['per_page'] = per_page
-        if page:
-            params['page'] = page
-        url = self.github_url + "/orgs/" + organization_name + "/repos"
+        query = "?per_page="+str(per_page)+"&page="+str(page)+"&type="+type+"&sort="+sort
+        url = self.github_url + "/orgs/" + organization_name + "/repos"+query
         return self.__request("GET", url, params)
 
     def repository(self, owner=None, repository_name=None):
@@ -163,6 +156,38 @@ class GithubUtilsApi:
         params = {}
         if protected:
             params['protected'] = protected
-        query = "?per_page="+per_page+"&page="+page
-        url = self.github_url + "/repos/" + owner + "/" + repository_name + "/branches"+query
+        query = "?per_page="+str(per_page)+"&page="+str(page)
+        url = self.github_url + "/repos/" + owner + "/" + repository_name + "/branches" + query
+        return self.__request("GET", url, params)
+
+    def recursive_get_all_repository_branches(self, organization_name, repository_name, page=1):
+        '''
+        This is a recursive method to get all repository branches using the method self.list_repository_branches
+        :param organization_name: string; name of the current organization created at github
+        :param repository_name: string; repository slug name
+        :param page: integer; Page number of the results to fetch. Default: 1
+        :return: Array of branches
+        '''
+        page_size = 30
+        list_branches = json.loads(self.list_repository_branches(owner=organization_name,repository_name=repository_name,per_page=page_size,page=page).text)
+        if len(list_branches) == page_size:
+            list_branches = list_branches + self.recursive_get_all_repository_branches(organization_name,repository_name,page+1)
+        else:
+            return list_branches
+        return list_branches
+
+    def repository_get_commit_details(self, owner, repository_name, reference, per_page=30, page=1):
+        '''
+        This method allows listing all details in a commit
+        According API docs: https://docs.github.com/es/rest/reference/commits#get-a-commit
+        :param owner: string; name of the current organization created at github or the owner
+        :param repository_name: string; repository slug name
+        :param reference: string; ref parameter
+        :param per_page: integer; Results per page (max 100). Default: 30
+        :param page: integer; Page number of the results to fetch. Default: 1
+        :return: commit details
+        '''
+        params = {}
+        query = "?per_page="+str(per_page)+"&page="+str(page)
+        url = self.github_url + "/repos/" + owner + "/" + repository_name + "/commits/" + reference + query
         return self.__request("GET", url, params)
\ No newline at end of file
